@@ -1,18 +1,18 @@
 #!/usr/bin/env python3
 import copy
 import json
-import ssl
 import sys
 from typing import List, Dict, Optional
+from urllib import parse
 
 import singer
 from pymongo import MongoClient
 from singer import metadata, metrics, utils
 
-import tap_mongodb.sync_strategies.change_streams as change_streams
-import tap_mongodb.sync_strategies.common as common
-import tap_mongodb.sync_strategies.full_table as full_table
-import tap_mongodb.sync_strategies.incremental as incremental
+from tap_mongodb.sync_strategies import change_streams
+from tap_mongodb.sync_strategies import common
+from tap_mongodb.sync_strategies import full_table
+from tap_mongodb.sync_strategies import incremental
 from tap_mongodb.config_utils import validate_config
 from tap_mongodb.db_utils import get_databases, produce_collection_schema
 from tap_mongodb.errors import InvalidReplicationMethodException, NoReadPrivilegeException
@@ -23,13 +23,14 @@ LOGGER = singer.get_logger('tap_mongodb')
 
 REQUIRED_CONFIG_KEYS = [
     'host',
-    'port',
     'user',
     'password',
     'auth_database',
     'database'
 ]
 
+REQUIRED_CONFIG_KEYS_NON_SRV = REQUIRED_CONFIG_KEYS + ['port']
+
 LOG_BASED_METHOD = 'LOG_BASED'
 INCREMENTAL_METHOD = 'INCREMENTAL'
 FULL_TABLE_METHOD = 'FULL_TABLE'
@@ -244,32 +245,60 @@ def do_sync(client: MongoClient, catalog: Dict, config: Dict, state: Dict):
     LOGGER.info(common.get_sync_summary(catalog))
 
 
+def get_connection_string(config: Dict):
+    """
+    Generates a MongoClientConnectionString based on configuration
+    Args:
+        config: DB config
+
+    Returns: A MongoClient connection string
+    """
+    srv = config.get('srv') == 'true'
+
+    # Default SSL verify mode to true, give option to disable
+    verify_mode = config.get('verify_mode', 'true') == 'true'
+    use_ssl = config.get('ssl') == 'true'
+
+    connection_query = {
+        'readPreference': 'secondaryPreferred',
+        'authSource': config['auth_database'],
+    }
+
+    if config.get('replica_set'):
+        connection_query['replicaSet'] = config['replica_set']
+
+    if use_ssl:
+        connection_query['tls'] = 'true'
+
+    # NB: "sslAllowInvalidCertificates" must ONLY be supplied if `SSL` is true.
+    if not verify_mode and use_ssl:
+        connection_query['tlsAllowInvalidCertificates'] = 'true'
+
+    query_string = parse.urlencode(connection_query)
+
+    port = "" if srv else f":{int(config['port'])}"
+
+    connection_string = f'{"mongodb+srv" if srv else "mongodb"}://{config["user"]}:' \
+                        f'{config["password"]}@{config["host"]}' \
+                        f'{port}/{config["database"]}?{query_string}'
+
+    return connection_string
+
+
 def main_impl():
     """
     Main function
     """
     args = utils.parse_args(REQUIRED_CONFIG_KEYS)
     config = args.config
+    srv = config.get('srv') == 'true'
 
-    # Default SSL verify mode to true, give option to disable
-    verify_mode = config.get('verify_mode', 'true') == 'true'
-    use_ssl = config.get('ssl') == 'true'
+    if not srv:
+        args = utils.parse_args(REQUIRED_CONFIG_KEYS_NON_SRV)
+        config = args.config
 
-    connection_params = {"host": config['host'],
-                         "port": int(config['port']),
-                         "username": config.get('user', None),
-                         "password": config.get('password', None),
-                         "authSource": config['auth_database'],
-                         "ssl": use_ssl,
-                         "replicaSet": config.get('replica_set', None),
-                         "readPreference": 'secondaryPreferred'
-                         }
-
-    # NB: "ssl_cert_reqs" must ONLY be supplied if `SSL` is true.
-    if not verify_mode and use_ssl:
-        connection_params["ssl_cert_reqs"] = ssl.CERT_NONE
-
-    client = MongoClient(**connection_params)
+    connection_string = get_connection_string(config)
+    client = MongoClient(connection_string)
 
     LOGGER.info('Connected to MongoDB host: %s, version: %s',
                 config['host'],
